@@ -1,7 +1,6 @@
 import json
 import os
 import re
-import shutil
 import subprocess
 import logging
 from collections import OrderedDict
@@ -10,6 +9,7 @@ from pathlib import Path
 
 import taf.settings as settings
 from taf.exceptions import (
+    TAFError,
     CloneRepoException,
     FetchException,
     InvalidRepositoryError,
@@ -17,6 +17,7 @@ from taf.exceptions import (
 )
 from taf.log import taf_logger
 from taf.utils import run
+from .pygit import PyGitRepository
 
 EMPTY_TREE = "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
 
@@ -29,6 +30,7 @@ class GitRepository:
         urls=None,
         custom=None,
         default_branch="main",
+        allow_unsafe=False,
         path=None,
         *args,
         **kwargs,
@@ -44,6 +46,8 @@ class GitRepository:
           urls (list): repository's urls
           custom (dict): a dictionary containing other data
           default_branch (str): repository's default branch ("main" if not defined)
+          allow_unsafe: allow a git's security mechanism which prevents execution of git commands if
+          the containing directory is owned by a different user to be ignored
         """
         if isinstance(library_dir, str):
             library_dir = Path(library_dir)
@@ -61,7 +65,7 @@ class GitRepository:
             self.library_dir = library_dir.resolve()
         elif path is None:
             raise InvalidRepositoryError(
-                "Either speicfy library dir and name pair or path!"
+                "Either specify library dir and name pair or path!"
             )
         else:
             # maintain support for repositories whose names are not of significance
@@ -83,6 +87,18 @@ class GitRepository:
         self.urls = self._validate_urls(urls)
         self.default_branch = default_branch
         self.custom = custom or {}
+        self.allow_unsafe = allow_unsafe
+
+    _pygit = None
+
+    @property
+    def pygit(self):
+        if self._pygit is None:
+            try:
+                self._pygit = PyGitRepository(self)
+            except Exception:
+                pass
+        return self._pygit
 
     @classmethod
     def from_json_dict(cls, json_data):
@@ -160,7 +176,10 @@ class GitRepository:
 
         if len(args):
             cmd = cmd.format(*args)
-        command = f"git -C {self.path} {cmd}"
+        if self.allow_unsafe:
+            command = f"git -C {self.path} -c safe.directory={self.path} {cmd}"
+        else:
+            command = f"git -C {self.path} {cmd}"
         result = None
         if log_error or log_error_msg:
             try:
@@ -416,10 +435,21 @@ class GitRepository:
     def clean(self):
         self._git("clean -fd")
 
+    def cleanup(self):
+        if self._pygit is not None:
+            self._pygit.cleanup()
+            self._pygit = None
+
     def clone(self, no_checkout=False, bare=False, **kwargs):
         self._log_info("cloning repository")
-        shutil.rmtree(self.path, True)
+
         self.path.mkdir(exist_ok=True, parents=True)
+        if len(os.listdir(self.path)) != 0:
+            raise GitError(
+                repo=self,
+                message=f"destination path {self.path} is not an empty directory.",
+            )
+
         if self.urls is None:
             raise GitError(
                 repo=self, message="cannot clone repository. No urls were specified"
@@ -607,9 +637,19 @@ class GitRepository:
         s = self.get_file(commit, path, raw=raw)
         return json.loads(s)
 
-    def get_file(self, commit, path, raw=False):
+    def get_file(self, commit, path, raw=False, with_id=False):
         path = Path(path).as_posix()
-        return self._git("show {}:{}", commit, path, raw=raw)
+        if raw:
+            return self._git("show {}:{}", commit, path, raw=raw)
+        try:
+            git_id, content = self.pygit.get_file(commit, path)
+            if with_id:
+                return git_id, content
+            return content
+        except TAFError as e:
+            raise e
+        except Exception:
+            return self._git("show {}:{}", commit, path, raw=raw)
 
     def get_first_commit_on_branch(self, branch=None):
         branch = branch or self.default_branch
@@ -714,6 +754,15 @@ class GitRepository:
         return False
 
     def list_files_at_revision(self, commit, path=""):
+        path = Path(path).as_posix()
+        try:
+            return self.pygit.list_files_at_revision(commit, path)
+        except TAFError as e:
+            raise e
+        except Exception:
+            return self._list_files_at_revision(commit, path)
+
+    def _list_files_at_revision(self, commit, path):
         if path is None:
             path = ""
         file_names = self._git("ls-tree -r --name-only {}", commit)
@@ -795,8 +844,9 @@ class GitRepository:
             for wt in worktrees
         }
 
-    def merge_commit(self, commit):
-        self._git("merge {}", commit, log_error=True)
+    def merge_commit(self, commit, fast_forward_only=False):
+        fast_forward_only_flag = "--ff-only" if fast_forward_only else ""
+        self._git("merge {} {}", commit, fast_forward_only_flag, log_error=True)
 
     def pull(self):
         """Pull current branch"""
@@ -921,19 +971,22 @@ class GitRepository:
         )
 
     def _validate_urls(self, urls):
+        def _find_url(path, url):
+            try:
+                if (path / url).resolve().is_dir():
+                    return str((path / url).resolve())
+            except OSError:
+                pass
+            if os.path.isabs(url):
+                return url
+            return str((path).resolve())
+
         if urls is not None:
             if settings.update_from_filesystem is False:
                 for url in urls:
                     self._validate_url(url)
             else:
-                urls = [
-                    str((self.path / url).resolve())
-                    if (self.path / url).resolve().is_dir()
-                    else str((self.path).resolve())
-                    if not os.path.isabs(url)
-                    else url
-                    for url in urls
-                ]
+                urls = [_find_url(self.path, url) for url in urls]
         return urls
 
 
