@@ -201,6 +201,7 @@ def update_repository(
     out_of_band_authentication=None,
     scripts_root_dir=None,
     checkout=True,
+    excluded_target_globs=None,
 ):
     """
     <Arguments>
@@ -267,83 +268,88 @@ def update_repository(
             out_of_band_authentication=out_of_band_authentication,
             scripts_root_dir=scripts_root_dir,
             checkout=checkout,
+            excluded_target_globs=excluded_target_globs,
         )
     except Exception as e:
         root_error = e
 
-    # after all repositories have been updated, sort them by hosts and call hosts handlers
-    # update information is in repos_update_data
-    if auth_repo_name not in repos_update_data:
-        # this must mean that an error occurred
-        if root_error is not None:
-            raise root_error
-        else:
-            raise UpdateFailedError(f"Update of {auth_repo_name} failed")
-    root_auth_repo = repos_update_data[auth_repo_name]["auth_repo"]
-    repos_and_commits = {
-        auth_repo_name: repo_data["commits_data"].get("after_pull")
-        for auth_repo_name, repo_data in repos_update_data.items()
-    }
-    try:
-        load_hosts(root_auth_repo, repos_and_commits)
-    except InvalidHostsError as e:
-        raise UpdateFailedError(str(e))
+    update_data = {}
+    if not excluded_target_globs:
+        # after all repositories have been updated, sort them by hosts and call hosts handlers
+        # update information is in repos_update_data
+        if auth_repo_name not in repos_update_data:
+            # this must mean that an error occurred
+            if root_error is not None:
+                raise root_error
+            else:
+                raise UpdateFailedError(f"Update of {auth_repo_name} failed")
+        root_auth_repo = repos_update_data[auth_repo_name]["auth_repo"]
+        repos_and_commits = {
+            auth_repo_name: repo_data["commits_data"].get("after_pull")
+            for auth_repo_name, repo_data in repos_update_data.items()
+        }
+        try:
+            load_hosts(root_auth_repo, repos_and_commits)
+        except InvalidHostsError as e:
+            raise UpdateFailedError(str(e))
 
-    hosts = get_hosts()
-    host_update_status = Event.UNCHANGED
-    errors = ""
-    update_transient_data = {}
+        hosts = get_hosts()
+        host_update_status = Event.UNCHANGED
+        errors = ""
+        update_transient_data = {}
 
-    for host in hosts:
-        # check if host update was successful - meaning that all repositories
-        # of that host were updated successfully
-        host_transient_data = {}
-        for host_data in host.data_by_auth_repo.values():
-            for host_repo_dict in host_data["auth_repos"]:
-                for host_repo_name in host_repo_dict:
-                    host_repo_update_data = repos_update_data[host_repo_name]
-                    update_status = host_repo_update_data["update_status"]
-                    if (
-                        host_update_status != update_status
-                        and host_update_status != Event.FAILED
-                    ):
-                        # if one failed, then failed
-                        # else if one changed, then changed
-                        # else unchanged
-                        host_update_status = update_status
-                    repo_error = host_repo_update_data["error"]
-                    if repo_error is not None:
-                        errors += str(repo_error)
-                if host_repo_name in transient_data:
-                    host_transient_data[host_repo_name] = transient_data[host_repo_name]
-                    update_transient_data[host_repo_name] = host_transient_data[
-                        host_repo_name
-                    ]
+        for host in hosts:
+            # check if host update was successful - meaning that all repositories
+            # of that host were updated successfully
+            host_transient_data = {}
+            for host_data in host.data_by_auth_repo.values():
+                for host_repo_dict in host_data["auth_repos"]:
+                    for host_repo_name in host_repo_dict:
+                        host_repo_update_data = repos_update_data[host_repo_name]
+                        update_status = host_repo_update_data["update_status"]
+                        if (
+                            host_update_status != update_status
+                            and host_update_status != Event.FAILED
+                        ):
+                            # if one failed, then failed
+                            # else if one changed, then changed
+                            # else unchanged
+                            host_update_status = update_status
+                        repo_error = host_repo_update_data["error"]
+                        if repo_error is not None:
+                            errors += str(repo_error)
+                    if host_repo_name in transient_data:
+                        host_transient_data[host_repo_name] = transient_data[
+                            host_repo_name
+                        ]
+                        update_transient_data[host_repo_name] = host_transient_data[
+                            host_repo_name
+                        ]
 
-        handle_host_event(
-            host_update_status,
-            host_transient_data,
-            root_auth_repo.library_dir,
-            scripts_root_dir,
-            host,
-            repos_update_data,
-            errors,
+            handle_host_event(
+                host_update_status,
+                host_transient_data,
+                root_auth_repo.library_dir,
+                scripts_root_dir,
+                host,
+                repos_update_data,
+                errors,
+            )
+
+        update_update_status, errors = _check_update_status(
+            repos_update_data, auth_repo_name, host_update_status, errors
         )
 
-    update_update_status, errors = _check_update_status(
-        repos_update_data, auth_repo_name, host_update_status, errors
-    )
-
-    update_data = handle_update_event(
-        update_update_status,
-        update_transient_data,
-        root_auth_repo.library_dir,
-        scripts_root_dir,
-        hosts,
-        repos_update_data,
-        errors,
-        root_auth_repo,
-    )
+        update_data = handle_update_event(
+            update_update_status,
+            update_transient_data,
+            root_auth_repo.library_dir,
+            scripts_root_dir,
+            hosts,
+            repos_update_data,
+            errors,
+            root_auth_repo,
+        )
 
     if root_error:
         raise root_error
@@ -370,6 +376,7 @@ def _update_named_repository(
     out_of_band_authentication=None,
     scripts_root_dir=None,
     checkout=True,
+    excluded_target_globs=None,
 ):
     """
     <Arguments>
@@ -447,6 +454,7 @@ def _update_named_repository(
         conf_directory_root,
         out_of_band_authentication,
         checkout,
+        excluded_target_globs,
     )
     # if auth_repo doesn't exist, means that either clients-auth-path isn't provided,
     # or info.json is missing from protected
@@ -540,12 +548,13 @@ def _update_named_repository(
             # if there were no errors, merge the last validated authentication repository commit
             _merge_commit(auth_repo, auth_repo.default_branch, last_commit, checkout)
             # update the last validated commit
-            auth_repo.set_last_validated_commit(last_commit)
+            if not excluded_target_globs:
+                auth_repo.set_last_validated_commit(last_commit)
 
         # do not call the handlers if only validating the repositories
         # if a handler fails and we are in the development mode, revert the update
         # so that it's easy to try again after fixing the handler
-        if not only_validate:
+        if not only_validate and not excluded_target_globs:
             _execute_repo_handlers(
                 update_status,
                 auth_repo,
@@ -586,6 +595,7 @@ def _update_current_repository(
     conf_directory_root,
     out_of_band_authentication,
     checkout,
+    excluded_target_globs,
 ):
     settings.update_from_filesystem = update_from_filesystem
     settings.conf_directory_root = conf_directory_root
@@ -707,13 +717,16 @@ def _update_current_repository(
             commits=commits,
             only_load_targets=False,
             default_branch=default_branch,
+            excluded_target_globs=excluded_target_globs,
         )
         repositories = repositoriesdb.get_deduplicated_repositories(
             users_auth_repo, commits
         )
         repositories_branches_and_commits = (
             users_auth_repo.sorted_commits_and_branches_per_repositories(
-                commits, default_branch=default_branch
+                commits,
+                default_branch=default_branch,
+                excluded_target_globs=excluded_target_globs,
             )
         )
 
